@@ -1,5 +1,5 @@
 import pickle
-
+import json
 import pandas as pd
 
 
@@ -9,7 +9,7 @@ def read_csv(file_path, sep=',', column_names=None, use_cols=None, squeeze=False
 
 def read_json(file_path):
     with open(file_path, 'r') as file:
-        return pd.read_json(file, lines=True)
+        return json.load(file)
 
 
 def read_pickle(file_path):
@@ -18,4 +18,7 @@ def read_pickle(file_path):
 
 
 def test_read():
-    print("je sais lire")
\ No newline at end of file
+    print("je sais lire")
+
+
+
