@@ -1,6 +1,6 @@
 import pickle
 import pandas as pd
-
+import json
 
 def write_pickle(file_path, data):
     with open(file_path, 'wb') as file:
@@ -13,7 +13,7 @@ def write_csv(file_path, data, sep=',', column_names=None):
 
 def write_json(file_path, data):
     with open(file_path, 'w') as file:
-        pd.json.dump(data.to_dict(), file)
+        json.dump(data, file)
 
 
 def test_write():
