@@ -22,3 +22,10 @@ def test_file_rw_pickle():
     assert obj == obj2
 
 
+def test_file_rw_json():
+    # Test the write functionality
+    obj = {'a': 1, 'b': 2}
+    file_rw('test_json', obj, mode='write', file_extension='json')
+    # Test the read functionality
+    obj2 = file_rw('test_json', mode='read', file_extension='json')
+    assert obj == obj2
\ No newline at end of file
